@@ -9,30 +9,41 @@ in Python with many simple yet powerful features.
 """
 
 from .client import Client
-from .errors import HTTPException, BadRequest, Unauthorized, Forbidden, RateLimited, ClientNotReady
-from .webhook import TopGGVotePayload, DiscordBotListVotePayload
-from .cog import NoTokenSet
-from .webhook import create_webhook_server, run_webhook_server
-
 from .dbl import DBLClient
+from .errors import (
+    BadRequest,
+    ClientNotReady,
+    ClientResponseError,
+    Forbidden,
+    HTTPException,
+    NoTokenSet,
+    RateLimited,
+    Unauthorized
+)
 from .topgg import TopGGClient
+from .webhook import create_webhook_server, DiscordBotListVotePayload, TopGGVotePayload
 
 
 __all__ = (
+    # client.py
     'Client',
-    'HTTPException',
-    'BadRequest',
-    'Unauthorized',
-    'Forbidden',
-    'RateLimited',
-    'ClientNotReady',
+    # dbl.py
     'DBLClient',
-    'TopGGClient',
-    'TopGGVotePayload',
-    'DiscordBotListVotePayload',
+    # errors
+    'BadRequest',
+    'ClientNotReady',
+    'ClientResponseError',
+    'Forbidden',
+    'HTTPException',
     'NoTokenSet',
+    'RateLimited',
+    'Unauthorized',
+    # topgg.py
+    'TopGGClient',
+    # webhook.py
     'create_webhook_server',
-    'run_webhook_server'
+    'DiscordBotListVotePayload',
+    'TopGGVotePayload'
 )
 
 
@@ -40,4 +51,4 @@ __title__ = 'toppy'
 __authors__ = ('The Master', 'chawkk6404')
 __license__ = 'MIT'
 __copyright__ = '2022-present The Master and chawkk6404'
-__version__ = '1.4.0'
+__version__ = '1.4.1'
