@@ -15,6 +15,11 @@ if TYPE_CHECKING:
     from .topgg import Bot, User
 
 
+__all__ = (
+    'Client'
+)
+
+
 class Client:
     """A class designed to handle both Top.gg and Discord Bot List.
     For individual handling use :class:`DBLClient` or :class:`TopGGClient`
@@ -72,7 +77,7 @@ class Client:
 
          Raises
          -------
-         :class:`TypeError` If it didn't receive :class:`float`, :class:`int`, or :class:`tuple`
+         :exc:`TypeError` If it didn't receive :class:`float`, :class:`int`, or :class:`tuple`
          """
         if isinstance(new, (float, int)):
             self.__dbl.interval = new
