@@ -1,27 +1,39 @@
 from typing import Optional
 
-from aiohttp import ClientResponse
+import aiohttp
 
 
 __all__ = (
-    'ClientNotReady',
     'BadRequest',
+    'ClientNotReady',
+    'ClientResponseError',
     'Forbidden',
     'HTTPException',
+    'NoTokenSet',
     'RateLimited',
     'Unauthorized'
 )
 
 
-class ClientNotReady(Exception):
+class NoTokenSet(Exception):
     def __init__(self):
-        message = 'The bot is not ready and does not have an application ID set so no ID could be found'
+        message = 'Create a bot var named "topgg_token" or "dbl_token" to use this cog.'
         super().__init__(message)
 
 
+class ClientResponseError(aiohttp.ClientResponseError):
+    """An alias of :class:`aiohttp.ClientResponseError`"""
+
+
+class ClientNotReady(Exception):
+    """The bot is not ready and does not have an application ID set so no ID could be found"""
+    def __init__(self):
+        super().__init__(ClientNotReady.__doc__)
+
+
 class HTTPException(Exception):
     """The base HTTP exception class."""
-    def __init__(self, resp: Optional[ClientResponse] = None, message: Optional[str] = None):
+    def __init__(self, resp: Optional[aiohttp.ClientResponse] = None, message: Optional[str] = None):
         self.resp = resp
 
         super().__init__(message or '')
@@ -44,6 +56,6 @@ class Forbidden(HTTPException):
 
 class RateLimited(HTTPException):
     """Status ``429``."""
-    def __init__(self, retry_after: Optional[int] = None, resp: Optional[ClientResponse] = None):
+    def __init__(self, retry_after: Optional[int] = None, resp: Optional[aiohttp.ClientResponse] = None):
         self.retry_after = retry_after
         super().__init__(resp, f'We have been ratelimited for the next {self.retry_after} seconds.')
